# UT Course Catalog

<p align="center">
  <a href="https://github.com/34j/ut-course-catalog/actions/workflows/ci.yml?query=branch%3Amain">
    <img src="https://img.shields.io/github/actions/workflow/status/34j/ut-course-catalog/ci.yml?branch=main&label=CI&logo=github&style=flat-square" alt="CI Status" >
  </a>
  <a href="https://ut-course-catalog.readthedocs.io">
    <img src="https://img.shields.io/readthedocs/ut-course-catalog.svg?logo=read-the-docs&logoColor=fff&style=flat-square" alt="Documentation Status">
  </a>
  <a href="https://codecov.io/gh/34j/ut-course-catalog">
    <img src="https://img.shields.io/codecov/c/github/34j/ut-course-catalog.svg?logo=codecov&logoColor=fff&style=flat-square" alt="Test coverage percentage">
  </a>
</p>
<p align="center">
  <a href="https://python-poetry.org/">
    <img src="https://img.shields.io/badge/packaging-poetry-299bd7?style=flat-square&logo=data:image/png;base64, " alt="Poetry">
  </a>
  <a href="https://github.com/ambv/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square" alt="black">
  </a>
  <a href="https://github.com/pre-commit/pre-commit">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square" alt="pre-commit">
  </a>
</p>
<p align="center">
  <a href="https://pypi.org/project/ut-course-catalog/">
    <img src="https://img.shields.io/pypi/v/ut-course-catalog.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/ut-course-catalog.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/ut-course-catalog.svg?style=flat-square" alt="License">
</p>

Python package for fetching UTokyo Online Course Catalogue

## Installation

Install this via pipx or pip (or your favourite package manager):

```shell
pipx install ut-course-catalog
```

## Dataset

- 東京大学授業カタログはインターネット上で公開されており、誰でも無償で入手可能でした。
- robots.txtの内容は寛容的であり、ページはWayback Machineに登録されているため、情報収集は禁止されていないと考えられました。

したがって、著作権法第三十条の四に基づいて、[データセット](https://www.kaggle.com/datasets/mkrjas/utokyosyllabus)をKaggleに公開しています。適当に解析したノートブック[(GitHub)](ut-course-catalog-tutorial.ipynb)もあります。

## Usage

1秒に1回のリクエストを送る場合、ダウンロードには4時間強かかります。負荷軽減のため、なるべく収集済みのデータセットを御利用ください。

```shell
ut-course-catalog download
ut-course-catalog convert all.pkl
```

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- prettier-ignore-start -->
<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- markdownlint-disable -->
<!-- markdownlint-enable -->
<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-end -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
